==> alt-lib-react-scripts-ts-2.16.4.tgz: package/template/.storybook/webpack.config.js <==
const path = require('path');

// load the default config generator.
const genDefaultConfig = require('@storybook/react/dist/server/config/defaults/webpack.config.js');
const testCssRule = "" + /\.css$/;
const testCssLoaderRx = /\bcss-loader\b/

module.exports = (baseConfig, env) => {
    const config = genDefaultConfig(baseConfig, 'development');

    // add alias
    config.resolve = config.resolve || {}
    config.resolve.alias = config.resolve.alias || {};
    config.resolve.alias["@node_modules"] = path.resolve(__dirname, "../node_modules");
    config.resolve.alias["@src"] = path.resolve(__dirname, "../src");
    config.resolve.alias["@api"] = path.resolve(__dirname, "../api");

    // CSS MODLUDES
    let cssRule = config.module.rules.find((r) => "" + r.test == testCssRule);
    if (cssRule) {
        let cssModules = cssRule.use.find((l) => testCssLoaderRx.test(l.loader));
        if (cssModules) {
            cssModules.options = cssModules.options || {};
            cssModules.options.modules = true;
            cssModules.options.sourceMap = true;
            cssModules.options.importLoaders = 1;
            cssModules.options.localIdentName = "[name]--[local]--[hash:base64:8]"
        }
    }

    // typescript
    config.module.rules.push({
        test: /\.(ts|tsx)$/,
        loader: require.resolve('ts-loader'),
        include: path.resolve(__dirname, '../')
    });
    config.resolve.extensions.push('.ts', '.tsx');

    // SASS
    config.module.rules.push({
        test: /\.scss$/,
        loaders: ["style-loader", "css-loader", "sass-loader"],
        include: path.resolve(__dirname, '../')
    });

    return config;
};

==> alt-lib-react-scripts-ts-2.16.5.tgz: package/template/.storybook/webpack.config.js <==
const path = require('path');
const TSDocgenPlugin = require("react-docgen-typescript-webpack-plugin");

const testCssRule = "" + /\.css$/;
const testCssLoaderRx = /\bcss-loader\b/

module.exports = (baseConfig, env, config) => {

    // add alias
    config.resolve = config.resolve || {}
    config.resolve.alias = config.resolve.alias || {};
    config.resolve.alias["@node_modules"] = path.resolve(__dirname, "../node_modules");
    config.resolve.alias["@src"] = path.resolve(__dirname, "../src");
    config.resolve.alias["@api"] = path.resolve(__dirname, "../api");

    // CSS MODLUDES
    let cssRule = config.module.rules.find((r) => "" + r.test == testCssRule);
    if (cssRule) {
        let cssModules = cssRule.use.find((l) => testCssLoaderRx.test(l.loader));
        if (cssModules) {
            cssModules.options = cssModules.options || {};
            cssModules.options.modules = true;
            cssModules.options.sourceMap = true;
            cssModules.options.importLoaders = 1;
            cssModules.options.localIdentName = "[name]--[local]--[hash:base64:8]"
        }
    }

    // typescript
    config.module.rules.push({
        test: /\.(ts|tsx)$/,
        loader: require.resolve('awesome-typescript-loader'),
        include: path.resolve(__dirname, '../')
    });
    config.plugins.push(new TSDocgenPlugin());
    config.resolve.extensions.push('.ts', '.tsx');

    // SASS
    config.module.rules.push({
        test: /\.scss$/,
        loaders: ["style-loader", "css-loader", "sass-loader"],
        include: path.resolve(__dirname, '../')
    });

    return config;
};
